@@ -4,7 +4,7 @@
 
 set -v
 
-python3 platform_setup/build_pdfium.py --check-deps
+python3 ./setupsrc/pl_setup/build_pdfium.py
 export PYP_TARGET_PLATFORM="sourcebuild"
-python3 -m build -n -x --wheel
 bash ./utilities/install.sh
+#python3 -m build -n -x --wheel
